##  Step 3: Upload Metadata to SAP LeanIX
  1. In SAP LeanIX, upload the metadata using a URL or an XML file.
  2. To validate the metadata, choose Validate.
  3. Choose Save.


![Screenshot showing the metadata upload interface with options to upload via URL or XML file, and validate and save buttons.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe5a61187c81f491586bb3ef838137bc8_LowRes.png)
Upload Metadata
